package_name = 'cms_search'
name = 'django-cms-search'
author = 'Divio AG'
author_email = 'developers@divio.ch'
description = "An extension to django CMS to provide multilingual Haystack indexes"
version = __import__(package_name).__version__
project_url = 'http://github.com/piquadrat/%s' % name
license = 'BSD'
